## UI QUnit test 

QUnit tests for the multiple UI elements used in this site

----
[web_components.qunit.html](/assets/qunit/webc/web_components.qunit.html)
{{iframe:/assets/qunit/webc/web_components.qunit.html}}

----
[WebC__Events_Utils.qunit.html](/assets/qunit/utils/WebC__Events_Utils.qunit.html)
{{iframe:/assets/qunit/utils/WebC__Events_Utils.qunit.html}}

----
[WebC__Events_Viewer.qunit.html](/assets/qunit/utils/WebC__Events_Viewer.qunit.html)
{{iframe:/assets/qunit/utils/WebC__Events_Viewer.qunit.html}}

----
[Chatbot_OpenAI.qunit.html](/assets/qunit/chat-bots/Chatbot_OpenAI.qunit.html)
{{iframe:/assets/qunit/chat-bots/Chatbot_OpenAI.qunit.html}}

----
[WebC__Chat_Bot.qunit.html](/assets/qunit/webc/elements/WebC__Chat_Bot.qunit.html)
{{iframe:/assets/qunit/webc/elements/WebC__Chat_Bot.qunit.html}}